==> pw-iso20022-SRU2024-9.5.0-sources.jar: com/prowidesoftware/swift/model/mx/dic/DataSetCategory18Code.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DataSetCategory18Code.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="DataSetCategory18Code"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="AQPR"/&gt;
 *     &lt;enumeration value="APPR"/&gt;
 *     &lt;enumeration value="TXCP"/&gt;
 *     &lt;enumeration value="AKCP"/&gt;
 *     &lt;enumeration value="DLGT"/&gt;
 *     &lt;enumeration value="MGTP"/&gt;
 *     &lt;enumeration value="MRPR"/&gt;
 *     &lt;enumeration value="SCPR"/&gt;
 *     &lt;enumeration value="SWPK"/&gt;
 *     &lt;enumeration value="STRP"/&gt;
 *     &lt;enumeration value="TRPR"/&gt;
 *     &lt;enumeration value="VDPR"/&gt;
 *     &lt;enumeration value="PARA"/&gt;
 *     &lt;enumeration value="TMSP"/&gt;
 *     &lt;enumeration value="CRTF"/&gt;
 *     &lt;enumeration value="LOGF"/&gt;
 *     &lt;enumeration value="CMRQ"/&gt;
 *     &lt;enumeration value="MDFL"/&gt;
 *     &lt;enumeration value="CONF"/&gt;
 *     &lt;enumeration value="RPFL"/&gt;
 *     &lt;enumeration value="SAPR"/&gt;
 *     &lt;enumeration value="SPRP"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "DataSetCategory18Code")
@XmlEnum
public enum DataSetCategory18Code {


    /**
     * Acquirer specific configuration parameters for the point of interaction (POI) system.
     * 
     */
    AQPR,

    /**
     * Payment application specific configuration parameters for the point of interaction (POI) system.
     * 
     */
    APPR,

    /**
     * Batch upload of transaction data (data capture of a group of transactions).
     * 
     */
    TXCP,

    /**
     * Batch download response for the batch capture of transactions.
     * 
     */
    AKCP,

    /**
     * Data needed to create a terminal management sub-domain.
     * 
     */
    DLGT,

    /**
     * Configuration of management plan in the point of interaction.
     * 
     */
    MGTP,

    /**
     * Merchant configuration parameters for the point of interaction (POI).
     * 
     */
    MRPR,

    /**
     * Point of interaction parameters related to the security of software application and application protocol.
     * 
     */
    SCPR,

    /**
     * Software module.
     * 
     */
    SWPK,

    /**
     * Report of software configuration and parameter status.
     * 
     */
    STRP,

    /**
     * Point of interaction parameters attached to the terminal as serial number or physical capabilities.
     * 
     */
    TRPR,

    /**
     * Point of interaction parameters defined by the manufacturer for instance the PIN verification capabilities.
     * 
     */
    VDPR,

    /**
     * Any combination of configuration parameters for the point of interaction (POI).
     * 
     */
    PARA,

    /**
     * Configuration parameters for the TMS protocol.
     * 
     */
    TMSP,

    /**
     * Certificate provided by a terminal manager.
     * 
     */
    CRTF,

    /**
     * Any repository used for recording log traces.
     * 
     */
    LOGF,

    /**
     * Trigger for CertificateManagementRequest.
     * 
     */
    CMRQ,

    /**
     * Media file managed by an application of the POI.
     * 
     */
    MDFL,

    /**
     * Configuration file relevant for the POI.
     * 
     */
    CONF,

    /**
     * Report file generated by the POI.
     * 
     */
    RPFL,

    /**
     * Parameters related to the Sale to POI protocol.
     * 
     */
    SAPR,

    /**
     * Service Provider specific parameters for the point of interaction (POI) system.
     * 
     */
    SPRP;

    public String value() {
        return name();
    }

    public static DataSetCategory18Code fromValue(String v) {
        return valueOf(v);
    }

}

==> pw-iso20022-SRU2024-10.2.3-sources.jar: com/prowidesoftware/swift/model/mx/dic/DataSetCategory18Code.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DataSetCategory18Code.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>{@code
 * <simpleType name="DataSetCategory18Code">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="AQPR"/>
 *     <enumeration value="APPR"/>
 *     <enumeration value="TXCP"/>
 *     <enumeration value="AKCP"/>
 *     <enumeration value="DLGT"/>
 *     <enumeration value="MGTP"/>
 *     <enumeration value="MRPR"/>
 *     <enumeration value="SCPR"/>
 *     <enumeration value="SWPK"/>
 *     <enumeration value="STRP"/>
 *     <enumeration value="TRPR"/>
 *     <enumeration value="VDPR"/>
 *     <enumeration value="PARA"/>
 *     <enumeration value="TMSP"/>
 *     <enumeration value="CRTF"/>
 *     <enumeration value="LOGF"/>
 *     <enumeration value="CMRQ"/>
 *     <enumeration value="MDFL"/>
 *     <enumeration value="CONF"/>
 *     <enumeration value="RPFL"/>
 *     <enumeration value="SAPR"/>
 *     <enumeration value="SPRP"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "DataSetCategory18Code")
@XmlEnum
public enum DataSetCategory18Code {


    /**
     * Acquirer specific configuration parameters for the point of interaction (POI) system.
     * 
     */
    AQPR,

    /**
     * Payment application specific configuration parameters for the point of interaction (POI) system.
     * 
     */
    APPR,

    /**
     * Batch upload of transaction data (data capture of a group of transactions).
     * 
     */
    TXCP,

    /**
     * Batch download response for the batch capture of transactions.
     * 
     */
    AKCP,

    /**
     * Data needed to create a terminal management sub-domain.
     * 
     */
    DLGT,

    /**
     * Configuration of management plan in the point of interaction.
     * 
     */
    MGTP,

    /**
     * Merchant configuration parameters for the point of interaction (POI).
     * 
     */
    MRPR,

    /**
     * Point of interaction parameters related to the security of software application and application protocol.
     * 
     */
    SCPR,

    /**
     * Software module.
     * 
     */
    SWPK,

    /**
     * Report of software configuration and parameter status.
     * 
     */
    STRP,

    /**
     * Point of interaction parameters attached to the terminal as serial number or physical capabilities.
     * 
     */
    TRPR,

    /**
     * Point of interaction parameters defined by the manufacturer for instance the PIN verification capabilities.
     * 
     */
    VDPR,

    /**
     * Any combination of configuration parameters for the point of interaction (POI).
     * 
     */
    PARA,

    /**
     * Configuration parameters for the TMS protocol.
     * 
     */
    TMSP,

    /**
     * Certificate provided by a terminal manager.
     * 
     */
    CRTF,

    /**
     * Any repository used for recording log traces.
     * 
     */
    LOGF,

    /**
     * Trigger for CertificateManagementRequest.
     * 
     */
    CMRQ,

    /**
     * Media file managed by an application of the POI.
     * 
     */
    MDFL,

    /**
     * Configuration file relevant for the POI.
     * 
     */
    CONF,

    /**
     * Report file generated by the POI.
     * 
     */
    RPFL,

    /**
     * Parameters related to the Sale to POI protocol.
     * 
     */
    SAPR,

    /**
     * Service Provider specific parameters for the point of interaction (POI) system.
     * 
     */
    SPRP;

    public String value() {
        return name();
    }

    public static DataSetCategory18Code fromValue(String v) {
        return valueOf(v);
    }

}
